@@ -1,5 +1,6 @@
 var searchData=
 [
+  ['libinput',['libinput',['../structlibinput.html',1,'']]],
   ['libinput_2eh',['libinput.h',['../libinput_8h.html',1,'']]],
   ['libinput_5fattribute_5fdeprecated',['LIBINPUT_ATTRIBUTE_DEPRECATED',['../libinput_8h.html#a765fe0783fd8cd83a82ecfe910780901',1,'libinput.h']]],
   ['libinput_5fattribute_5fprintf',['LIBINPUT_ATTRIBUTE_PRINTF',['../libinput_8h.html#a7de828556e8e12b23e4c5acec1581780',1,'libinput.h']]],
@@ -23,7 +24,7 @@ var searchData=
   ['libinput_5fconfig_5ftap_5fdisabled',['LIBINPUT_CONFIG_TAP_DISABLED',['../group__config.html#ggaca4a3177736e6fd024cb77bc684857a1ab202825f96206e91e8faa8c379b81b11',1,'libinput.h']]],
   ['libinput_5fconfig_5ftap_5fenabled',['LIBINPUT_CONFIG_TAP_ENABLED',['../group__config.html#ggaca4a3177736e6fd024cb77bc684857a1ab3cb0b659d23d21b0b55c676899af92a',1,'libinput.h']]],
   ['libinput_5fconfig_5ftap_5fstate',['libinput_config_tap_state',['../group__config.html#gaca4a3177736e6fd024cb77bc684857a1',1,'libinput.h']]],
-  ['libinput_5fdevice_5fcalibrate',['libinput_device_calibrate',['../group__device.html#ga4e4cd9682dea5278545da7091b772126',1,'libinput.h']]],
+  ['libinput_5fdevice',['libinput_device',['../structlibinput__device.html',1,'']]],
   ['libinput_5fdevice_5fcap_5fkeyboard',['LIBINPUT_DEVICE_CAP_KEYBOARD',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15a733315d968cac7bd569b43b71664ae4b',1,'libinput.h']]],
   ['libinput_5fdevice_5fcap_5fpointer',['LIBINPUT_DEVICE_CAP_POINTER',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15a6e7c3249a8f0503fce7e0a5effc4d73f',1,'libinput.h']]],
   ['libinput_5fdevice_5fcap_5ftouch',['LIBINPUT_DEVICE_CAP_TOUCH',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15aad61f92a8154c9017d4e621c768712aa',1,'libinput.h']]],
@@ -32,14 +33,14 @@ var searchData=
   ['libinput_5fdevice_5fconfig_5faccel_5fget_5fspeed',['libinput_device_config_accel_get_speed',['../group__config.html#gaac7c1b31e0131154d31b9167c876cc3b',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fis_5favailable',['libinput_device_config_accel_is_available',['../group__config.html#ga77b20c16fe26f385936f1d8cb4a1a560',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fset_5fspeed',['libinput_device_config_accel_set_speed',['../group__config.html#ga1d9761bb99b445524fb2ea801f946ef1',1,'libinput.h']]],
-  ['libinput_5fdevice_5fconfig_5fbuttons_5fget_5fdefault_5fleft_5fhanded',['libinput_device_config_buttons_get_default_left_handed',['../group__config.html#gab14d80ce7c67e895e9012ff4acf5ed61',1,'libinput.h']]],
-  ['libinput_5fdevice_5fconfig_5fbuttons_5fget_5fleft_5fhanded',['libinput_device_config_buttons_get_left_handed',['../group__config.html#gaf49649a1550ac28e489647e78db95138',1,'libinput.h']]],
-  ['libinput_5fdevice_5fconfig_5fbuttons_5fhas_5fleft_5fhanded',['libinput_device_config_buttons_has_left_handed',['../group__config.html#ga2ef3c4badcf90a636c9a0c292dbbd874',1,'libinput.h']]],
-  ['libinput_5fdevice_5fconfig_5fbuttons_5fset_5fleft_5fhanded',['libinput_device_config_buttons_set_left_handed',['../group__config.html#ga56b0b55a07092df406d506e6ca425194',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fdefault_5fmatrix',['libinput_device_config_calibration_get_default_matrix',['../group__config.html#ga3d9f1b9be10e804e170c4ea455bd1f1b',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fmatrix',['libinput_device_config_calibration_get_matrix',['../group__config.html#gaa16e8b272ce94f8037822dc8c89d84a5',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fhas_5fmatrix',['libinput_device_config_calibration_has_matrix',['../group__config.html#gadd921b0caef6fcf05199a93e5ee0728b',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fset_5fmatrix',['libinput_device_config_calibration_set_matrix',['../group__config.html#ga09a798f58cc601edd2797780096e9804',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fget',['libinput_device_config_left_handed_get',['../group__config.html#ga998945b1c4f96a9abd3c3a26e5c4166c',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fget_5fdefault',['libinput_device_config_left_handed_get_default',['../group__config.html#gaa438a14e32894791e435cb43826ef3a9',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fis_5favailable',['libinput_device_config_left_handed_is_available',['../group__config.html#ga755352f2bbb869446aa591dd9d9c5eaf',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fset',['libinput_device_config_left_handed_set',['../group__config.html#ga9bbdef04c07804ce7c121133c04d4edf',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fbutton',['libinput_device_config_scroll_get_button',['../group__config.html#ga83623da437d0114b8e3ac29ab771d799',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fbutton',['libinput_device_config_scroll_get_default_button',['../group__config.html#gad4aacefb10fab1e401e211ee9ce0c1e6',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fmethod',['libinput_device_config_scroll_get_default_method',['../group__config.html#ga844ea06b952aaee8e0643d85d351afb6',1,'libinput.h']]],
@@ -62,7 +63,6 @@ var searchData=
   ['libinput_5fdevice_5fget_5fcontext',['libinput_device_get_context',['../group__device.html#ga90c6868911d8aba103278c9208d5205e',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fid_5fproduct',['libinput_device_get_id_product',['../group__device.html#gae011910b4a673f1293a20a84be4e52e2',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fid_5fvendor',['libinput_device_get_id_vendor',['../group__device.html#gad9e4c074b03da790de5e117c71ce8d50',1,'libinput.h']]],
-  ['libinput_5fdevice_5fget_5fkeys',['libinput_device_get_keys',['../group__device.html#gaae16aef7966ef373492eca957c3ecd10',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fname',['libinput_device_get_name',['../group__device.html#ga31655d2c2f173d059b3f891801c0a429',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5foutput_5fname',['libinput_device_get_output_name',['../group__device.html#gaf48626f6190e9c9bc14abb704e66cc22',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fseat',['libinput_device_get_seat',['../group__device.html#ga27823edb40750992a1a05e7a9f5dc8f0',1,'libinput.h']]],
@@ -78,8 +78,10 @@ var searchData=
   ['libinput_5fdevice_5fset_5fuser_5fdata',['libinput_device_set_user_data',['../group__device.html#ga6243ad6005b2ce2a5ecfd1b04787fe93',1,'libinput.h']]],
   ['libinput_5fdevice_5funref',['libinput_device_unref',['../group__device.html#ga857340e2dab06c7f7d84173a5a1fa427',1,'libinput.h']]],
   ['libinput_5fdispatch',['libinput_dispatch',['../group__base.html#ga271f910ed17461830e48d4cd20483a00',1,'libinput.h']]],
+  ['libinput_5fevent',['libinput_event',['../structlibinput__event.html',1,'']]],
   ['libinput_5fevent_5fdestroy',['libinput_event_destroy',['../group__event.html#ga1df956c16e26cbbd911e553ec081022a',1,'libinput.h']]],
   ['libinput_5fevent_5fdevice_5fadded',['LIBINPUT_EVENT_DEVICE_ADDED',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca4da18343b29cc16ae2df09b9a3bff33b',1,'libinput.h']]],
+  ['libinput_5fevent_5fdevice_5fnotify',['libinput_event_device_notify',['../structlibinput__event__device__notify.html',1,'']]],
   ['libinput_5fevent_5fdevice_5fnotify_5fget_5fbase_5fevent',['libinput_event_device_notify_get_base_event',['../group__event.html#ga19d329b7685c3a994718cec3845db1a0',1,'libinput.h']]],
   ['libinput_5fevent_5fdevice_5fremoved',['LIBINPUT_EVENT_DEVICE_REMOVED',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca971332bb0efebbfb240001466684dd09',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fcontext',['libinput_event_get_context',['../group__event.html#ga28557ae0295f61c45f9b6e4ff7f86632',1,'libinput.h']]],
@@ -89,6 +91,7 @@ var searchData=
   ['libinput_5fevent_5fget_5fpointer_5fevent',['libinput_event_get_pointer_event',['../group__event.html#ga52acdc3afcf75efeb8153f50eef20615',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5ftouch_5fevent',['libinput_event_get_touch_event',['../group__event.html#gad2cba8252024bdcc341499bedd3d0be7',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5ftype',['libinput_event_get_type',['../group__event.html#ga430a3a7369afd6c5ff722179327df79a',1,'libinput.h']]],
+  ['libinput_5fevent_5fkeyboard',['libinput_event_keyboard',['../structlibinput__event__keyboard.html',1,'']]],
   ['libinput_5fevent_5fkeyboard_5fget_5fbase_5fevent',['libinput_event_keyboard_get_base_event',['../group__event__keyboard.html#gae5a3b7e12e7e8b213b3da92a13adb88d',1,'libinput.h']]],
   ['libinput_5fevent_5fkeyboard_5fget_5fkey',['libinput_event_keyboard_get_key',['../group__event__keyboard.html#gad29cc9f276d9468463d01f65ccf8deaf',1,'libinput.h']]],
   ['libinput_5fevent_5fkeyboard_5fget_5fkey_5fstate',['libinput_event_keyboard_get_key_state',['../group__event__keyboard.html#gaf7b018edbc264ba81a2d475d42ebbd98',1,'libinput.h']]],
@@ -96,14 +99,16 @@ var searchData=
   ['libinput_5fevent_5fkeyboard_5fget_5ftime',['libinput_event_keyboard_get_time',['../group__event__keyboard.html#ga0f1a7bb1016816a277b52705d6ef2d71',1,'libinput.h']]],
   ['libinput_5fevent_5fkeyboard_5fkey',['LIBINPUT_EVENT_KEYBOARD_KEY',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca477833897722f621bd10bbf3771302d3',1,'libinput.h']]],
   ['libinput_5fevent_5fnone',['LIBINPUT_EVENT_NONE',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7cabccc2f8bdff4e6ff42d3e1318864af67',1,'libinput.h']]],
+  ['libinput_5fevent_5fpointer',['libinput_event_pointer',['../structlibinput__event__pointer.html',1,'']]],
   ['libinput_5fevent_5fpointer_5faxis',['LIBINPUT_EVENT_POINTER_AXIS',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca507673764d93c8d46109b069a3ab9bde',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fbutton',['LIBINPUT_EVENT_POINTER_BUTTON',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca26d8ced7a6e63edefb7f72ddd4d1d689',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fx',['libinput_event_pointer_get_absolute_x',['../group__event__pointer.html#gac221536b90c7beb70b70b52e710291b5',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fx_5ftransformed',['libinput_event_pointer_get_absolute_x_transformed',['../group__event__pointer.html#ga26fa3d0b2bcc7f0a7939b84dc8207021',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fy',['libinput_event_pointer_get_absolute_y',['../group__event__pointer.html#ga3e097a9bc6dbbb355fb1982912f72d4c',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fy_5ftransformed',['libinput_event_pointer_get_absolute_y_transformed',['../group__event__pointer.html#gaa48effb21f132f05f280859f3d2a9f23',1,'libinput.h']]],
-  ['libinput_5fevent_5fpointer_5fget_5faxis',['libinput_event_pointer_get_axis',['../group__event__pointer.html#gace6f44c48d7696d989d5be38afaba817',1,'libinput.h']]],
-  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue',['libinput_event_pointer_get_axis_value',['../group__event__pointer.html#gaba288dcf55de6e2691fd75f31229f969',1,'libinput.h']]],
+  ['libinput_5fevent_5fpointer_5fget_5faxis_5fsource',['libinput_event_pointer_get_axis_source',['../group__event__pointer.html#ga2116f4bbedb61532e71d16c4f87bd4ca',1,'libinput.h']]],
+  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue',['libinput_event_pointer_get_axis_value',['../group__event__pointer.html#ga81ad7d8a95c456731a874e584c4c8dda',1,'libinput.h']]],
+  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue_5fdiscrete',['libinput_event_pointer_get_axis_value_discrete',['../libinput_8h.html#a38d12fc6884c9943e261febdb2384b98',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fbase_5fevent',['libinput_event_pointer_get_base_event',['../group__event__pointer.html#ga4d4f75669001c323dcdc3cc9aec1574a',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fbutton',['libinput_event_pointer_get_button',['../group__event__pointer.html#ga6dc942e706a29d342a2021afaa49548b',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fbutton_5fstate',['libinput_event_pointer_get_button_state',['../group__event__pointer.html#ga41e87521ab2a8b7783cb47a63d71da18',1,'libinput.h']]],
@@ -113,6 +118,7 @@ var searchData=
   ['libinput_5fevent_5fpointer_5fget_5fdy_5funaccelerated',['libinput_event_pointer_get_dy_unaccelerated',['../group__event__pointer.html#ga2a9d66358432b4bee5f8c201f8dc8906',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fseat_5fbutton_5fcount',['libinput_event_pointer_get_seat_button_count',['../group__event__pointer.html#ga1990b268bdc42ff3277bc43dbb3102ea',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5ftime',['libinput_event_pointer_get_time',['../group__event__pointer.html#gac42d0e19d076f4e1fca15f1ec42510d5',1,'libinput.h']]],
+  ['libinput_5fevent_5fpointer_5fhas_5faxis',['libinput_event_pointer_has_axis',['../group__event__pointer.html#ga1fdd37a49eae958aaf78a0596cd5cef5',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fmotion',['LIBINPUT_EVENT_POINTER_MOTION',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca1812725b7fac7f096cb5d667a6bf89e9',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fmotion_5fabsolute',['LIBINPUT_EVENT_POINTER_MOTION_ABSOLUTE',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca5e277107f22df970e882ef76dd6cc315',1,'libinput.h']]],
   ['libinput_5fevent_5ftouch',['libinput_event_touch',['../structlibinput__event__touch.html',1,'']]],
@@ -156,8 +162,13 @@ var searchData=
   ['libinput_5fpointer_5faxis',['libinput_pointer_axis',['../group__device.html#ga82cd15b9476a4a60f25470df8d67483c',1,'libinput.h']]],
   ['libinput_5fpointer_5faxis_5fscroll_5fhorizontal',['LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL',['../group__device.html#gga82cd15b9476a4a60f25470df8d67483caf0618a16f29ca56a8df0b624442f9852',1,'libinput.h']]],
   ['libinput_5fpointer_5faxis_5fscroll_5fvertical',['LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL',['../group__device.html#gga82cd15b9476a4a60f25470df8d67483ca538dfb7d4ab598030af4d57aac55a1e5',1,'libinput.h']]],
+  ['libinput_5fpointer_5faxis_5fsource',['libinput_pointer_axis_source',['../group__device.html#ga76c012d8f6d7656fb795dc7bdf9d6551',1,'libinput.h']]],
+  ['libinput_5fpointer_5faxis_5fsource_5fcontinuous',['LIBINPUT_POINTER_AXIS_SOURCE_CONTINUOUS',['../group__device.html#gga76c012d8f6d7656fb795dc7bdf9d6551a3843fac25b1895de1d05191daf4527f6',1,'libinput.h']]],
+  ['libinput_5fpointer_5faxis_5fsource_5ffinger',['LIBINPUT_POINTER_AXIS_SOURCE_FINGER',['../group__device.html#gga76c012d8f6d7656fb795dc7bdf9d6551a6a55790b11ef0aaecb897329d29a9fbb',1,'libinput.h']]],
+  ['libinput_5fpointer_5faxis_5fsource_5fwheel',['LIBINPUT_POINTER_AXIS_SOURCE_WHEEL',['../group__device.html#gga76c012d8f6d7656fb795dc7bdf9d6551a60e7f4a41ceda06fe3eba2d512dc8ec9',1,'libinput.h']]],
   ['libinput_5fref',['libinput_ref',['../group__base.html#gafff29392ec52e1e7de5bb812e085127a',1,'libinput.h']]],
   ['libinput_5fresume',['libinput_resume',['../group__base.html#ga5a1ee92fa05df27e3c0f37d524cc17a6',1,'libinput.h']]],
+  ['libinput_5fseat',['libinput_seat',['../structlibinput__seat.html',1,'']]],
   ['libinput_5fseat_5fget_5fcontext',['libinput_seat_get_context',['../group__seat.html#ga634ac38cf583d1da4e99824860d91efc',1,'libinput.h']]],
   ['libinput_5fseat_5fget_5flogical_5fname',['libinput_seat_get_logical_name',['../group__seat.html#ga61e477120d5f0cc67a06d04575186948',1,'libinput.h']]],
   ['libinput_5fseat_5fget_5fphysical_5fname',['libinput_seat_get_physical_name',['../group__seat.html#gac881036869846ad87eb7814fbf308251',1,'libinput.h']]],
@@ -165,8 +176,10 @@ var searchData=
   ['libinput_5fseat_5fref',['libinput_seat_ref',['../group__seat.html#ga60445ab81e8ee3a10b85e88617231069',1,'libinput.h']]],
   ['libinput_5fseat_5fset_5fuser_5fdata',['libinput_seat_set_user_data',['../group__seat.html#ga669ed8a095445e9537deef8a9880587b',1,'libinput.h']]],
   ['libinput_5fseat_5funref',['libinput_seat_unref',['../group__seat.html#ga81d52d0e9332f07c39a899c8c2fd3400',1,'libinput.h']]],
+  ['libinput_5fset_5fuser_5fdata',['libinput_set_user_data',['../group__base.html#gac1a020ab0a0da92749e24e80538ab28f',1,'libinput.h']]],
   ['libinput_5fsuspend',['libinput_suspend',['../group__base.html#ga60662dc666f6188dc207467c9d8e99ab',1,'libinput.h']]],
   ['libinput_5fudev_5fassign_5fseat',['libinput_udev_assign_seat',['../group__base.html#ga71a60660b30cb476495e75766222d144',1,'libinput.h']]],
   ['libinput_5fudev_5fcreate_5fcontext',['libinput_udev_create_context',['../group__base.html#ga7512ea602d4b259085c47f6374b078d1',1,'libinput.h']]],
-  ['libinput_5funref',['libinput_unref',['../group__base.html#ga7ed0797d23e34b650e0aeb98b5350309',1,'libinput.h']]]
+  ['libinput_5funref',['libinput_unref',['../group__base.html#ga7ed0797d23e34b650e0aeb98b5350309',1,'libinput.h']]],
+  ['lenovo_20_2a40_20series_20touchpad_20support',['Lenovo *40 series touchpad support',['../t440_support.html',1,'']]]
 ];
