@@ -10,5 +10,6 @@ var searchData=
   ['libinput_5fkey_5fstate',['libinput_key_state',['../group__device.html#ga360bdea89a75606472a0b5d72678bd17',1,'libinput.h']]],
   ['libinput_5fled',['libinput_led',['../group__device.html#ga37ec9afaec2e5407e3c5248faedd1970',1,'libinput.h']]],
   ['libinput_5flog_5fpriority',['libinput_log_priority',['../libinput_8h.html#aa7e9ebbd1a13fe2ed6f44e69df3216e1',1,'libinput.h']]],
-  ['libinput_5fpointer_5faxis',['libinput_pointer_axis',['../group__device.html#ga82cd15b9476a4a60f25470df8d67483c',1,'libinput.h']]]
+  ['libinput_5fpointer_5faxis',['libinput_pointer_axis',['../group__device.html#ga82cd15b9476a4a60f25470df8d67483c',1,'libinput.h']]],
+  ['libinput_5fpointer_5faxis_5fsource',['libinput_pointer_axis_source',['../group__device.html#ga76c012d8f6d7656fb795dc7bdf9d6551',1,'libinput.h']]]
 ];
