@@ -1,19 +1,18 @@
 var searchData=
 [
   ['libinput_5fconfig_5fstatus_5fto_5fstr',['libinput_config_status_to_str',['../group__config.html#ga7eee5ba99988d80bb9dd744894c72e06',1,'libinput.h']]],
-  ['libinput_5fdevice_5fcalibrate',['libinput_device_calibrate',['../group__device.html#ga4e4cd9682dea5278545da7091b772126',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fget_5fdefault_5fspeed',['libinput_device_config_accel_get_default_speed',['../group__config.html#ga71fba19df9d2cb15904c6351cec1af35',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fget_5fspeed',['libinput_device_config_accel_get_speed',['../group__config.html#gaac7c1b31e0131154d31b9167c876cc3b',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fis_5favailable',['libinput_device_config_accel_is_available',['../group__config.html#ga77b20c16fe26f385936f1d8cb4a1a560',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fset_5fspeed',['libinput_device_config_accel_set_speed',['../group__config.html#ga1d9761bb99b445524fb2ea801f946ef1',1,'libinput.h']]],
-  ['libinput_5fdevice_5fconfig_5fbuttons_5fget_5fdefault_5fleft_5fhanded',['libinput_device_config_buttons_get_default_left_handed',['../group__config.html#gab14d80ce7c67e895e9012ff4acf5ed61',1,'libinput.h']]],
-  ['libinput_5fdevice_5fconfig_5fbuttons_5fget_5fleft_5fhanded',['libinput_device_config_buttons_get_left_handed',['../group__config.html#gaf49649a1550ac28e489647e78db95138',1,'libinput.h']]],
-  ['libinput_5fdevice_5fconfig_5fbuttons_5fhas_5fleft_5fhanded',['libinput_device_config_buttons_has_left_handed',['../group__config.html#ga2ef3c4badcf90a636c9a0c292dbbd874',1,'libinput.h']]],
-  ['libinput_5fdevice_5fconfig_5fbuttons_5fset_5fleft_5fhanded',['libinput_device_config_buttons_set_left_handed',['../group__config.html#ga56b0b55a07092df406d506e6ca425194',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fdefault_5fmatrix',['libinput_device_config_calibration_get_default_matrix',['../group__config.html#ga3d9f1b9be10e804e170c4ea455bd1f1b',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fmatrix',['libinput_device_config_calibration_get_matrix',['../group__config.html#gaa16e8b272ce94f8037822dc8c89d84a5',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fhas_5fmatrix',['libinput_device_config_calibration_has_matrix',['../group__config.html#gadd921b0caef6fcf05199a93e5ee0728b',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fset_5fmatrix',['libinput_device_config_calibration_set_matrix',['../group__config.html#ga09a798f58cc601edd2797780096e9804',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fget',['libinput_device_config_left_handed_get',['../group__config.html#ga998945b1c4f96a9abd3c3a26e5c4166c',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fget_5fdefault',['libinput_device_config_left_handed_get_default',['../group__config.html#gaa438a14e32894791e435cb43826ef3a9',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fis_5favailable',['libinput_device_config_left_handed_is_available',['../group__config.html#ga755352f2bbb869446aa591dd9d9c5eaf',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fset',['libinput_device_config_left_handed_set',['../group__config.html#ga9bbdef04c07804ce7c121133c04d4edf',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fbutton',['libinput_device_config_scroll_get_button',['../group__config.html#ga83623da437d0114b8e3ac29ab771d799',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fbutton',['libinput_device_config_scroll_get_default_button',['../group__config.html#gad4aacefb10fab1e401e211ee9ce0c1e6',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fmethod',['libinput_device_config_scroll_get_default_method',['../group__config.html#ga844ea06b952aaee8e0643d85d351afb6',1,'libinput.h']]],
@@ -36,7 +35,6 @@ var searchData=
   ['libinput_5fdevice_5fget_5fcontext',['libinput_device_get_context',['../group__device.html#ga90c6868911d8aba103278c9208d5205e',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fid_5fproduct',['libinput_device_get_id_product',['../group__device.html#gae011910b4a673f1293a20a84be4e52e2',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fid_5fvendor',['libinput_device_get_id_vendor',['../group__device.html#gad9e4c074b03da790de5e117c71ce8d50',1,'libinput.h']]],
-  ['libinput_5fdevice_5fget_5fkeys',['libinput_device_get_keys',['../group__device.html#gaae16aef7966ef373492eca957c3ecd10',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fname',['libinput_device_get_name',['../group__device.html#ga31655d2c2f173d059b3f891801c0a429',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5foutput_5fname',['libinput_device_get_output_name',['../group__device.html#gaf48626f6190e9c9bc14abb704e66cc22',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fseat',['libinput_device_get_seat',['../group__device.html#ga27823edb40750992a1a05e7a9f5dc8f0',1,'libinput.h']]],
@@ -70,8 +68,9 @@ var searchData=
   ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fx_5ftransformed',['libinput_event_pointer_get_absolute_x_transformed',['../group__event__pointer.html#ga26fa3d0b2bcc7f0a7939b84dc8207021',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fy',['libinput_event_pointer_get_absolute_y',['../group__event__pointer.html#ga3e097a9bc6dbbb355fb1982912f72d4c',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fy_5ftransformed',['libinput_event_pointer_get_absolute_y_transformed',['../group__event__pointer.html#gaa48effb21f132f05f280859f3d2a9f23',1,'libinput.h']]],
-  ['libinput_5fevent_5fpointer_5fget_5faxis',['libinput_event_pointer_get_axis',['../group__event__pointer.html#gace6f44c48d7696d989d5be38afaba817',1,'libinput.h']]],
-  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue',['libinput_event_pointer_get_axis_value',['../group__event__pointer.html#gaba288dcf55de6e2691fd75f31229f969',1,'libinput.h']]],
+  ['libinput_5fevent_5fpointer_5fget_5faxis_5fsource',['libinput_event_pointer_get_axis_source',['../group__event__pointer.html#ga2116f4bbedb61532e71d16c4f87bd4ca',1,'libinput.h']]],
+  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue',['libinput_event_pointer_get_axis_value',['../group__event__pointer.html#ga81ad7d8a95c456731a874e584c4c8dda',1,'libinput.h']]],
+  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue_5fdiscrete',['libinput_event_pointer_get_axis_value_discrete',['../libinput_8h.html#a38d12fc6884c9943e261febdb2384b98',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fbase_5fevent',['libinput_event_pointer_get_base_event',['../group__event__pointer.html#ga4d4f75669001c323dcdc3cc9aec1574a',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fbutton',['libinput_event_pointer_get_button',['../group__event__pointer.html#ga6dc942e706a29d342a2021afaa49548b',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fbutton_5fstate',['libinput_event_pointer_get_button_state',['../group__event__pointer.html#ga41e87521ab2a8b7783cb47a63d71da18',1,'libinput.h']]],
@@ -81,6 +80,7 @@ var searchData=
   ['libinput_5fevent_5fpointer_5fget_5fdy_5funaccelerated',['libinput_event_pointer_get_dy_unaccelerated',['../group__event__pointer.html#ga2a9d66358432b4bee5f8c201f8dc8906',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5fseat_5fbutton_5fcount',['libinput_event_pointer_get_seat_button_count',['../group__event__pointer.html#ga1990b268bdc42ff3277bc43dbb3102ea',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5ftime',['libinput_event_pointer_get_time',['../group__event__pointer.html#gac42d0e19d076f4e1fca15f1ec42510d5',1,'libinput.h']]],
+  ['libinput_5fevent_5fpointer_5fhas_5faxis',['libinput_event_pointer_has_axis',['../group__event__pointer.html#ga1fdd37a49eae958aaf78a0596cd5cef5',1,'libinput.h']]],
   ['libinput_5fevent_5ftouch_5fget_5fbase_5fevent',['libinput_event_touch_get_base_event',['../group__event__touch.html#gacb2cd144a719c9873cd4621db278e92c',1,'libinput.h']]],
   ['libinput_5fevent_5ftouch_5fget_5fseat_5fslot',['libinput_event_touch_get_seat_slot',['../group__event__touch.html#gabac75c78a0a360995e1a521edb38c4da',1,'libinput.h']]],
   ['libinput_5fevent_5ftouch_5fget_5fslot',['libinput_event_touch_get_slot',['../group__event__touch.html#gaf5294eab86b9125b7fb607049ff9ef09',1,'libinput.h']]],
@@ -107,6 +107,7 @@ var searchData=
   ['libinput_5fseat_5fref',['libinput_seat_ref',['../group__seat.html#ga60445ab81e8ee3a10b85e88617231069',1,'libinput.h']]],
   ['libinput_5fseat_5fset_5fuser_5fdata',['libinput_seat_set_user_data',['../group__seat.html#ga669ed8a095445e9537deef8a9880587b',1,'libinput.h']]],
   ['libinput_5fseat_5funref',['libinput_seat_unref',['../group__seat.html#ga81d52d0e9332f07c39a899c8c2fd3400',1,'libinput.h']]],
+  ['libinput_5fset_5fuser_5fdata',['libinput_set_user_data',['../group__base.html#gac1a020ab0a0da92749e24e80538ab28f',1,'libinput.h']]],
   ['libinput_5fsuspend',['libinput_suspend',['../group__base.html#ga60662dc666f6188dc207467c9d8e99ab',1,'libinput.h']]],
   ['libinput_5fudev_5fassign_5fseat',['libinput_udev_assign_seat',['../group__base.html#ga71a60660b30cb476495e75766222d144',1,'libinput.h']]],
   ['libinput_5fudev_5fcreate_5fcontext',['libinput_udev_create_context',['../group__base.html#ga7512ea602d4b259085c47f6374b078d1',1,'libinput.h']]],
