@@ -69,7 +69,7 @@ tp_edge_scroll_set_state(struct tp_dispatch *tp,
 {
 	libinput_timer_cancel(&t->scroll.timer);
 
-	t->scroll.state = state;
+	t->scroll.edge_state = state;
 
 	switch (state) {
 	case EDGE_SCROLL_TOUCH_STATE_NONE:
@@ -113,7 +113,8 @@ tp_edge_scroll_handle_none(struct tp_dispatch *tp,
 	case SCROLL_EVENT_TIMEOUT:
 	case SCROLL_EVENT_POSTED:
 		log_bug_libinput(libinput,
-				 "unexpect scroll event in none state\n");
+				 "unexpected scroll event %d in none state\n",
+				 event);
 		break;
 	}
 }
@@ -128,7 +129,8 @@ tp_edge_scroll_handle_edge_new(struct tp_dispatch *tp,
 	switch (event) {
 	case SCROLL_EVENT_TOUCH:
 		log_bug_libinput(libinput,
-				 "unexpect scroll event in edge new state\n");
+				 "unexpected scroll event %d in edge new state\n",
+				 event);
 		break;
 	case SCROLL_EVENT_MOTION:
 		t->scroll.edge &= tp_touch_get_edge(tp, t);
@@ -157,7 +159,8 @@ tp_edge_scroll_handle_edge(struct tp_dispatch *tp,
 	case SCROLL_EVENT_TOUCH:
 	case SCROLL_EVENT_TIMEOUT:
 		log_bug_libinput(libinput,
-				 "unexpect scroll event in edge state\n");
+				 "unexpected scroll event %d in edge state\n",
+				 event);
 		break;
 	case SCROLL_EVENT_MOTION:
 		/* If started at the bottom right, decide in which dir to scroll */
@@ -188,7 +191,8 @@ tp_edge_scroll_handle_area(struct tp_dispatch *tp,
 	case SCROLL_EVENT_TIMEOUT:
 	case SCROLL_EVENT_POSTED:
 		log_bug_libinput(libinput,
-				 "unexpect scroll event in area state\n");
+				 "unexpected scroll event %d in area state\n",
+				 event);
 		break;
 	case SCROLL_EVENT_MOTION:
 		break;
@@ -203,7 +207,7 @@ tp_edge_scroll_handle_event(struct tp_dispatch *tp,
 			    struct tp_touch *t,
 			    enum scroll_event event)
 {
-	switch (t->scroll.state) {
+	switch (t->scroll.edge_state) {
 	case EDGE_SCROLL_TOUCH_STATE_NONE:
 		tp_edge_scroll_handle_none(tp, t, event);
 		break;
@@ -271,7 +275,7 @@ tp_edge_scroll_init(struct tp_dispatch *tp, struct evdev_device *device)
 }
 
 void
-tp_destroy_edge_scroll(struct tp_dispatch *tp)
+tp_remove_edge_scroll(struct tp_dispatch *tp)
 {
 	struct tp_touch *t;
 
@@ -321,7 +325,10 @@ tp_edge_scroll_post_events(struct tp_dispatch *tp, uint64_t time)
 				if (t->scroll.direction != -1) {
 					/* Send stop scroll event */
 					pointer_notify_axis(device, time,
-						t->scroll.direction, 0.0);
+						AS_MASK(t->scroll.direction),
+						LIBINPUT_POINTER_AXIS_SOURCE_FINGER,
+						0.0, 0.0,
+						0, 0);
 					t->scroll.direction = -1;
 				}
 				continue;
@@ -343,7 +350,11 @@ tp_edge_scroll_post_events(struct tp_dispatch *tp, uint64_t time)
 		if (fabs(*delta) < t->scroll.threshold)
 			continue;
 
-		pointer_notify_axis(device, time, axis, *delta);
+		pointer_notify_axis(device, time,
+				    AS_MASK(axis),
+				    LIBINPUT_POINTER_AXIS_SOURCE_FINGER,
+				    dx, dy,
+				    0, 0);
 		t->scroll.direction = axis;
 
 		tp_edge_scroll_handle_event(tp, t, SCROLL_EVENT_POSTED);
@@ -361,7 +372,10 @@ tp_edge_scroll_stop_events(struct tp_dispatch *tp, uint64_t time)
 	tp_for_each_touch(tp, t) {
 		if (t->scroll.direction != -1) {
 			pointer_notify_axis(device, time,
-					    t->scroll.direction, 0.0);
+					    AS_MASK(t->scroll.direction),
+					    LIBINPUT_POINTER_AXIS_SOURCE_FINGER,
+					    0.0, 0.0,
+					    0.0, 0.0);
 			t->scroll.direction = -1;
 		}
 	}
@@ -370,5 +384,5 @@ tp_edge_scroll_stop_events(struct tp_dispatch *tp, uint64_t time)
 int
 tp_edge_scroll_touch_active(struct tp_dispatch *tp, struct tp_touch *t)
 {
-	return t->scroll.state == EDGE_SCROLL_TOUCH_STATE_AREA;
+	return t->scroll.edge_state == EDGE_SCROLL_TOUCH_STATE_AREA;
 }
