@@ -177,7 +177,7 @@ tp_estimate_delta(int x0, int x1, int x2, int x3)
 void
 tp_get_delta(struct tp_touch *t, double *dx, double *dy)
 {
-	if (t->history.count < 4) {
+	if (t->history.count < TOUCHPAD_MIN_SAMPLES) {
 		*dx = 0;
 		*dy = 0;
 		return;
@@ -435,7 +435,39 @@ tp_post_twofinger_scroll(struct tp_dispatch *tp, uint64_t time)
 
 	tp_filter_motion(tp, &dx, &dy, NULL, NULL, time);
 
-	evdev_post_scroll(tp->device, time, dx, dy);
+	evdev_post_scroll(tp->device,
+			  time,
+			  LIBINPUT_POINTER_AXIS_SOURCE_FINGER,
+			  dx, dy);
+	tp->scroll.twofinger_state = TWOFINGER_SCROLL_STATE_ACTIVE;
+}
+
+static void
+tp_twofinger_stop_scroll(struct tp_dispatch *tp, uint64_t time)
+{
+	struct tp_touch *t, *ptr = NULL;
+	int nfingers_down = 0;
+
+	evdev_stop_scroll(tp->device,
+			  time,
+			  LIBINPUT_POINTER_AXIS_SOURCE_FINGER);
+
+	/* If we were scrolling and now there's exactly 1 active finger,
+	   switch back to pointer movement */
+	if (tp->scroll.twofinger_state == TWOFINGER_SCROLL_STATE_ACTIVE) {
+		tp_for_each_touch(tp, t) {
+			if (tp_touch_active(tp, t)) {
+				nfingers_down++;
+				if (ptr == NULL)
+					ptr = t;
+			}
+		}
+
+		if (nfingers_down == 1)
+			tp_set_pointer(tp, ptr);
+	}
+
+	tp->scroll.twofinger_state = TWOFINGER_SCROLL_STATE_NONE;
 }
 
 static int
@@ -448,19 +480,24 @@ tp_twofinger_scroll_post_events(struct tp_dispatch *tp, uint64_t time)
 	if (tp_tap_dragging(tp))
 		return 0;
 
+	/* No 2fg scrolling while a clickpad is clicked */
+	if (tp->buttons.is_clickpad && tp->buttons.state)
+		return 0;
+
 	/* Only count active touches for 2 finger scrolling */
 	tp_for_each_touch(tp, t) {
 		if (tp_touch_active(tp, t))
 			nfingers_down++;
 	}
 
-	if (nfingers_down != 2) {
-		evdev_stop_scroll(tp->device, time);
-		return 0;
+	if (nfingers_down == 2) {
+		tp_post_twofinger_scroll(tp, time);
+		return 1;
 	}
 
-	tp_post_twofinger_scroll(tp, time);
-	return 1;
+	tp_twofinger_stop_scroll(tp, time);
+
+	return 0;
 }
 
 static void
@@ -500,7 +537,7 @@ tp_stop_scroll_events(struct tp_dispatch *tp, uint64_t time)
 	case LIBINPUT_CONFIG_SCROLL_NO_SCROLL:
 		break;
 	case LIBINPUT_CONFIG_SCROLL_2FG:
-		evdev_stop_scroll(tp->device, time);
+		tp_twofinger_stop_scroll(tp, time);
 		break;
 	case LIBINPUT_CONFIG_SCROLL_EDGE:
 		tp_edge_scroll_stop_events(tp, time);
@@ -512,9 +549,9 @@ tp_stop_scroll_events(struct tp_dispatch *tp, uint64_t time)
 }
 
 static void
-tp_destroy_scroll(struct tp_dispatch *tp)
+tp_remove_scroll(struct tp_dispatch *tp)
 {
-	tp_destroy_edge_scroll(tp);
+	tp_remove_edge_scroll(tp);
 }
 
 static void
@@ -586,14 +623,67 @@ tp_post_process_state(struct tp_dispatch *tp, uint64_t time)
 	tp->queued = TOUCHPAD_EVENT_NONE;
 }
 
+static void
+tp_get_pointer_delta(struct tp_dispatch *tp, double *dx, double *dy)
+{
+	struct tp_touch *t = tp_current_touch(tp);
+
+	if (!t->is_pointer) {
+		tp_for_each_touch(tp, t) {
+			if (t->is_pointer)
+				break;
+		}
+	}
+
+	if (!t->is_pointer || !t->dirty)
+		return;
+
+	tp_get_delta(t, dx, dy);
+}
+
+static void
+tp_get_active_touches_delta(struct tp_dispatch *tp, double *dx, double *dy)
+{
+	struct tp_touch *t;
+	double tdx, tdy;
+	unsigned int i;
+
+	for (i = 0; i < tp->real_touches; i++) {
+		t = tp_get_touch(tp, i);
+
+		if (!tp_touch_active(tp, t) || !t->dirty)
+			continue;
+
+		tp_get_delta(t, &tdx, &tdy);
+		*dx += tdx;
+		*dy += tdy;
+	}
+}
+
+static void
+tp_post_pointer_motion(struct tp_dispatch *tp, uint64_t time)
+{
+	double dx = 0.0, dy = 0.0;
+	double dx_unaccel, dy_unaccel;
+
+	/* When a clickpad is clicked, combine motion of all active touches */
+	if (tp->buttons.is_clickpad && tp->buttons.state)
+		tp_get_active_touches_delta(tp, &dx, &dy);
+	else
+		tp_get_pointer_delta(tp, &dx, &dy);
+
+	tp_filter_motion(tp, &dx, &dy, &dx_unaccel, &dy_unaccel, time);
+
+	if (dx != 0.0 || dy != 0.0 || dx_unaccel != 0.0 || dy_unaccel != 0.0) {
+		pointer_notify_motion(&tp->device->base, time,
+				      dx, dy, dx_unaccel, dy_unaccel);
+	}
+}
 
 static void
 tp_post_events(struct tp_dispatch *tp, uint64_t time)
 {
-	struct tp_touch *t = tp_current_touch(tp);
-	double dx, dy;
 	int filter_motion = 0;
-	double dx_unaccel, dy_unaccel;
 
 	/* Only post (top) button events while suspended */
 	if (tp->device->suspended) {
@@ -612,25 +702,7 @@ tp_post_events(struct tp_dispatch *tp, uint64_t time)
 	if (tp_post_scroll_events(tp, time) != 0)
 		return;
 
-	if (!t->is_pointer) {
-		tp_for_each_touch(tp, t) {
-			if (t->is_pointer)
-				break;
-		}
-	}
-
-	if (!t->is_pointer ||
-	    !t->dirty ||
-	    t->history.count < TOUCHPAD_MIN_SAMPLES)
-		return;
-
-	tp_get_delta(t, &dx, &dy);
-	tp_filter_motion(tp, &dx, &dy, &dx_unaccel, &dy_unaccel, time);
-
-	if (dx != 0.0 || dy != 0.0 || dx_unaccel != 0.0 || dy_unaccel != 0.0) {
-		pointer_notify_motion(&tp->device->base, time,
-				      dx, dy, dx_unaccel, dy_unaccel);
-	}
+	tp_post_pointer_motion(tp, time);
 }
 
 static void
@@ -668,7 +740,7 @@ tp_process(struct evdev_dispatch *dispatch,
 }
 
 static void
-tp_destroy_sendevents(struct tp_dispatch *tp)
+tp_remove_sendevents(struct tp_dispatch *tp)
 {
 	libinput_timer_cancel(&tp->sendevents.trackpoint_timer);
 
@@ -677,16 +749,24 @@ tp_destroy_sendevents(struct tp_dispatch *tp)
 					&tp->sendevents.trackpoint_listener);
 }
 
+static void
+tp_remove(struct evdev_dispatch *dispatch)
+{
+	struct tp_dispatch *tp =
+		(struct tp_dispatch*)dispatch;
+
+	tp_remove_tap(tp);
+	tp_remove_buttons(tp);
+	tp_remove_sendevents(tp);
+	tp_remove_scroll(tp);
+}
+
 static void
 tp_destroy(struct evdev_dispatch *dispatch)
 {
 	struct tp_dispatch *tp =
 		(struct tp_dispatch*)dispatch;
 
-	tp_destroy_tap(tp);
-	tp_destroy_buttons(tp);
-	tp_destroy_sendevents(tp);
-	tp_destroy_scroll(tp);
 
 	free(tp->touches);
 	free(tp);
@@ -771,7 +851,9 @@ tp_trackpoint_event(uint64_t time, struct libinput_event *event, void *data)
 		return;
 
 	if (!tp->sendevents.trackpoint_active) {
-		evdev_stop_scroll(tp->device, time);
+		evdev_stop_scroll(tp->device,
+				  time,
+				  LIBINPUT_POINTER_AXIS_SOURCE_FINGER);
 		tp_tap_suspend(tp, time);
 		tp->sendevents.trackpoint_active = true;
 	}
@@ -858,6 +940,7 @@ tp_tag_device(struct evdev_device *device,
 
 static struct evdev_dispatch_interface tp_interface = {
 	tp_process,
+	tp_remove,
 	tp_destroy,
 	tp_device_added,
 	tp_device_removed,
@@ -1227,7 +1310,7 @@ tp_change_to_left_handed(struct evdev_device *device)
 {
 	struct tp_dispatch *tp = (struct tp_dispatch *)device->dispatch;
 
-	if (device->buttons.want_left_handed == device->buttons.left_handed)
+	if (device->left_handed.want_enabled == device->left_handed.enabled)
 		return;
 
 	if (tp->buttons.state & 0x3) /* BTN_LEFT|BTN_RIGHT */
@@ -1236,7 +1319,7 @@ tp_change_to_left_handed(struct evdev_device *device)
 	/* tapping and clickfinger aren't affected by left-handed config,
 	 * so checking physical buttons is enough */
 
-	device->buttons.left_handed = device->buttons.want_left_handed;
+	device->left_handed.enabled = device->left_handed.want_enabled;
 }
 
 struct model_lookup_t {
