@@ -117,6 +117,11 @@ enum tp_edge_scroll_touch_state {
 	EDGE_SCROLL_TOUCH_STATE_AREA,
 };
 
+enum tp_twofinger_scroll_state {
+	TWOFINGER_SCROLL_STATE_NONE,
+	TWOFINGER_SCROLL_STATE_ACTIVE,
+};
+
 struct tp_motion {
 	int32_t x;
 	int32_t y;
@@ -165,7 +170,7 @@ struct tp_touch {
 	} tap;
 
 	struct {
-		enum tp_edge_scroll_touch_state state;
+		enum tp_edge_scroll_touch_state edge_state;
 		uint32_t edge;
 		int direction;
 		double threshold;
@@ -238,6 +243,7 @@ struct tp_dispatch {
 		enum libinput_config_scroll_method method;
 		int32_t right_edge;
 		int32_t bottom_edge;
+		enum tp_twofinger_scroll_state twofinger_state;
 	} scroll;
 
 	enum touchpad_event queued;
@@ -287,7 +293,7 @@ int
 tp_init_tap(struct tp_dispatch *tp);
 
 void
-tp_destroy_tap(struct tp_dispatch *tp);
+tp_remove_tap(struct tp_dispatch *tp);
 
 int
 tp_init_buttons(struct tp_dispatch *tp, struct evdev_device *device);
@@ -298,7 +304,7 @@ tp_init_softbuttons(struct tp_dispatch *tp,
 		    double topbutton_size_mult);
 
 void
-tp_destroy_buttons(struct tp_dispatch *tp);
+tp_remove_buttons(struct tp_dispatch *tp);
 
 int
 tp_process_button(struct tp_dispatch *tp,
@@ -338,7 +344,7 @@ int
 tp_edge_scroll_init(struct tp_dispatch *tp, struct evdev_device *device);
 
 void
-tp_destroy_edge_scroll(struct tp_dispatch *tp);
+tp_remove_edge_scroll(struct tp_dispatch *tp);
 
 void
 tp_edge_scroll_handle_state(struct tp_dispatch *tp, uint64_t time);
