@@ -119,6 +119,9 @@ struct evdev_device {
 		/* set during device init if we want natural scrolling,
 		 * used at runtime to enable/disable the feature */
 		bool natural_scrolling_enabled;
+
+		/* angle per REL_WHEEL click in degrees */
+		int wheel_click_angle;
 	} scroll;
 
 	enum evdev_event_type pending_event;
@@ -141,15 +144,15 @@ struct evdev_device {
 	uint8_t key_count[KEY_CNT];
 
 	struct {
-		struct libinput_device_config_left_handed config_left_handed;
+		struct libinput_device_config_left_handed config;
 		/* left-handed currently enabled */
-		bool left_handed;
+		bool enabled;
 		/* set during device init if we want left_handed config,
 		 * used at runtime to delay the effect until buttons are up */
-		bool want_left_handed;
+		bool want_enabled;
 		/* Checks if buttons are down and commits the setting */
-		void (*change_to_left_handed)(struct evdev_device *device);
-	} buttons;
+		void (*change_to_enabled)(struct evdev_device *device);
+	} left_handed;
 
 	int dpi; /* HW resolution */
 	struct ratelimit syn_drop_limit; /* ratelimit for SYN_DROPPED logging */
@@ -166,6 +169,9 @@ struct evdev_dispatch_interface {
 			struct input_event *event,
 			uint64_t time);
 
+	/* Device is being removed (may be NULL) */
+	void (*remove)(struct evdev_dispatch *dispatch);
+
 	/* Destroy an event dispatch handler and free all its resources. */
 	void (*destroy)(struct evdev_dispatch *dispatch);
 
@@ -295,12 +301,15 @@ evdev_init_natural_scroll(struct evdev_device *device);
 void
 evdev_post_scroll(struct evdev_device *device,
 		  uint64_t time,
+		  enum libinput_pointer_axis_source source,
 		  double dx,
 		  double dy);
 
 
 void
-evdev_stop_scroll(struct evdev_device *device, uint64_t time);
+evdev_stop_scroll(struct evdev_device *device,
+		  uint64_t time,
+		  enum libinput_pointer_axis_source source);
 
 void
 evdev_device_remove(struct evdev_device *device);
@@ -323,7 +332,7 @@ static inline uint32_t
 evdev_to_left_handed(struct evdev_device *device,
 		     uint32_t button)
 {
-	if (device->buttons.left_handed) {
+	if (device->left_handed.enabled) {
 		if (button == BTN_LEFT)
 			return BTN_RIGHT;
 		else if (button == BTN_RIGHT)
