@@ -162,6 +162,8 @@ void litest_assert_button_event(struct libinput *li,
 void litest_assert_scroll(struct libinput *li,
 			  enum libinput_pointer_axis axis,
 			  int minimum_movement);
+void litest_assert_only_typed_events(struct libinput *li,
+				     enum libinput_event_type type);
 
 struct libevdev_uinput * litest_create_uinput_device(const char *name,
 						     struct input_id *id,
