@@ -121,7 +121,6 @@ START_TEST(touchpad_1fg_tap_n_drag)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
-	struct libinput_event *event;
 
 	libinput_device_config_tap_set_enabled(dev->libinput_device,
 					       LIBINPUT_CONFIG_TAP_ENABLED);
@@ -140,27 +139,15 @@ START_TEST(touchpad_1fg_tap_n_drag)
 				   LIBINPUT_BUTTON_STATE_PRESSED);
 
 	libinput_dispatch(li);
-	while (libinput_next_event_type(li) == LIBINPUT_EVENT_POINTER_MOTION) {
-		event = libinput_get_event(li);
-		libinput_event_destroy(event);
-		libinput_dispatch(li);
-	}
 
-	ck_assert_int_eq(libinput_next_event_type(li), LIBINPUT_EVENT_NONE);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	/* lift finger, set down again, should continue dragging */
 	litest_touch_down(dev, 0, 50, 50);
 	litest_touch_move_to(dev, 0, 50, 50, 80, 80, 5, 40);
 	litest_touch_up(dev, 0);
 
-	libinput_dispatch(li);
-	while (libinput_next_event_type(li) == LIBINPUT_EVENT_POINTER_MOTION) {
-		event = libinput_get_event(li);
-		libinput_event_destroy(event);
-		libinput_dispatch(li);
-	}
-
-	ck_assert_int_eq(libinput_next_event_type(li), LIBINPUT_EVENT_NONE);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	litest_timeout_tap();
 
@@ -204,29 +191,23 @@ START_TEST(touchpad_2fg_tap_n_drag)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
-	struct libinput_event *event;
 
 	libinput_device_config_tap_set_enabled(dev->libinput_device,
 					       LIBINPUT_CONFIG_TAP_ENABLED);
 
 	litest_drain_events(li);
 
-	litest_touch_down(dev, 0, 50, 50);
+	litest_touch_down(dev, 0, 30, 70);
 	litest_touch_up(dev, 0);
-	litest_touch_down(dev, 0, 50, 50);
-	litest_touch_down(dev, 1, 60, 50);
-	litest_touch_move_to(dev, 0, 50, 50, 80, 80, 5, 40);
+	litest_touch_down(dev, 0, 30, 70);
+	litest_touch_down(dev, 1, 80, 70);
+	litest_touch_move_to(dev, 0, 30, 70, 30, 30, 5, 40);
 	libinput_dispatch(li);
 
 	litest_assert_button_event(li, BTN_LEFT,
 				   LIBINPUT_BUTTON_STATE_PRESSED);
 
-	while (libinput_next_event_type(li) == LIBINPUT_EVENT_POINTER_MOTION) {
-		event = libinput_get_event(li);
-		libinput_event_destroy(event);
-		libinput_dispatch(li);
-	}
-	litest_assert_empty_queue(li);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
@@ -243,29 +224,23 @@ START_TEST(touchpad_2fg_tap_n_drag_3fg_btntool)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
-	struct libinput_event *event;
 
 	libinput_device_config_tap_set_enabled(dev->libinput_device,
 					       LIBINPUT_CONFIG_TAP_ENABLED);
 
 	litest_drain_events(li);
 
-	litest_touch_down(dev, 0, 50, 50);
+	litest_touch_down(dev, 0, 30, 70);
 	litest_touch_up(dev, 0);
-	litest_touch_down(dev, 0, 50, 50);
-	litest_touch_down(dev, 1, 60, 50);
-	litest_touch_move_to(dev, 0, 50, 50, 80, 80, 5, 40);
+	litest_touch_down(dev, 0, 30, 70);
+	litest_touch_down(dev, 1, 80, 90);
+	litest_touch_move_to(dev, 0, 30, 70, 30, 30, 5, 40);
 	libinput_dispatch(li);
 
 	litest_assert_button_event(li, BTN_LEFT,
 				   LIBINPUT_BUTTON_STATE_PRESSED);
 
-	while (libinput_next_event_type(li) == LIBINPUT_EVENT_POINTER_MOTION) {
-		event = libinput_get_event(li);
-		libinput_event_destroy(event);
-		libinput_dispatch(li);
-	}
-	litest_assert_empty_queue(li);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	/* Putting down a third finger should end the drag */
 	litest_event(dev, EV_KEY, BTN_TOOL_TRIPLETAP, 1);
@@ -591,7 +566,6 @@ START_TEST(touchpad_1fg_tap_n_drag_click)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
-	struct libinput_event *event;
 
 	libinput_device_config_tap_set_enabled(dev->libinput_device,
 					       LIBINPUT_CONFIG_TAP_ENABLED);
@@ -608,15 +582,7 @@ START_TEST(touchpad_1fg_tap_n_drag_click)
 	litest_assert_button_event(li, BTN_LEFT,
 				   LIBINPUT_BUTTON_STATE_PRESSED);
 
-	libinput_dispatch(li);
-
-	ck_assert_int_eq(libinput_next_event_type(li),
-			 LIBINPUT_EVENT_POINTER_MOTION);
-	while (libinput_next_event_type(li) == LIBINPUT_EVENT_POINTER_MOTION) {
-		event = libinput_get_event(li);
-		libinput_event_destroy(event);
-		libinput_dispatch(li);
-	}
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	litest_event(dev, EV_KEY, BTN_LEFT, 1);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
@@ -873,7 +839,6 @@ START_TEST(clickpad_click_n_drag)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
-	struct libinput_event *event;
 
 	litest_drain_events(li);
 
@@ -893,14 +858,7 @@ START_TEST(clickpad_click_n_drag)
 	litest_touch_move_to(dev, 1, 70, 70, 80, 50, 5, 0);
 	litest_touch_up(dev, 1);
 
-	libinput_dispatch(li);
-	ck_assert_int_eq(libinput_next_event_type(li),
-			 LIBINPUT_EVENT_POINTER_MOTION);
-	do {
-		event = libinput_get_event(li);
-		libinput_event_destroy(event);
-		libinput_dispatch(li);
-	} while (libinput_next_event_type(li) == LIBINPUT_EVENT_POINTER_MOTION);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	litest_event(dev, EV_KEY, BTN_LEFT, 0);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
@@ -924,7 +882,7 @@ START_TEST(clickpad_softbutton_left)
 
 	litest_assert_button_event(li,
 				   BTN_LEFT,
-			    LIBINPUT_BUTTON_STATE_PRESSED);
+				   LIBINPUT_BUTTON_STATE_PRESSED);
 
 	litest_event(dev, EV_KEY, BTN_LEFT, 0);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
@@ -932,7 +890,7 @@ START_TEST(clickpad_softbutton_left)
 
 	litest_assert_button_event(li,
 				   BTN_LEFT,
-			    LIBINPUT_BUTTON_STATE_RELEASED);
+				   LIBINPUT_BUTTON_STATE_RELEASED);
 
 	libinput_dispatch(li);
 
@@ -1481,18 +1439,19 @@ START_TEST(touchpad_2fg_scroll_slow_distance)
 
 	/* last event is value 0, tested elsewhere */
 	while (libinput_next_event_type(li) != LIBINPUT_EVENT_NONE) {
+		double axisval;
 		ck_assert_int_eq(libinput_event_get_type(event),
 				 LIBINPUT_EVENT_POINTER_AXIS);
 		ptrev = libinput_event_get_pointer_event(event);
 
-		ck_assert_int_eq(libinput_event_pointer_get_axis(ptrev),
-				 LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL);
-		ck_assert(libinput_event_pointer_get_axis_value(ptrev) > 0.0);
+		axisval = libinput_event_pointer_get_axis_value(ptrev,
+				LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL);
+		ck_assert(axisval > 0.0);
 
 		/* this is to verify we test the right thing, if the value
 		   is greater than scroll.threshold we triggered the wrong
 		   condition */
-		ck_assert(libinput_event_pointer_get_axis_value(ptrev) < 5.0);
+		ck_assert(axisval < 5.0);
 
 		libinput_event_destroy(event);
 		event = libinput_get_event(li);
@@ -1503,6 +1462,67 @@ START_TEST(touchpad_2fg_scroll_slow_distance)
 }
 END_TEST
 
+START_TEST(touchpad_2fg_scroll_source)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libinput *li = dev->libinput;
+	struct libinput_event *event;
+	struct libinput_event_pointer *ptrev;
+
+	litest_drain_events(li);
+
+	test_2fg_scroll(dev, 0, 20, 0);
+	litest_wait_for_event_of_type(li, LIBINPUT_EVENT_POINTER_AXIS, -1);
+
+	while ((event = libinput_get_event(li))) {
+		ck_assert_int_eq(libinput_event_get_type(event),
+				 LIBINPUT_EVENT_POINTER_AXIS);
+		ptrev = libinput_event_get_pointer_event(event);
+		ck_assert_int_eq(libinput_event_pointer_get_axis_source(ptrev),
+				 LIBINPUT_POINTER_AXIS_SOURCE_FINGER);
+		libinput_event_destroy(event);
+	}
+}
+END_TEST
+
+START_TEST(touchpad_2fg_scroll_return_to_motion)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libinput *li = dev->libinput;
+
+	litest_drain_events(li);
+
+	/* start with motion */
+	litest_touch_down(dev, 0, 70, 70);
+	litest_touch_move_to(dev, 0, 70, 70, 47, 50, 10, 0);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
+
+	/* 2fg scroll */
+	litest_touch_down(dev, 1, 53, 50);
+	litest_touch_move_to(dev, 0, 47, 50, 47, 70, 5, 0);
+	litest_touch_move_to(dev, 1, 53, 50, 53, 70, 5, 0);
+	litest_touch_up(dev, 1);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_AXIS);
+
+	litest_touch_move_to(dev, 0, 47, 70, 47, 50, 10, 0);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
+
+	/* back to 2fg scroll, lifting the other finger */
+	litest_touch_down(dev, 1, 50, 50);
+	litest_touch_move_to(dev, 0, 47, 50, 47, 70, 5, 0);
+	litest_touch_move_to(dev, 1, 53, 50, 53, 70, 5, 0);
+	litest_touch_up(dev, 0);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_AXIS);
+
+	/* move with second finger */
+	litest_touch_move_to(dev, 1, 53, 70, 53, 50, 10, 0);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
+
+	litest_touch_up(dev, 1);
+	litest_assert_empty_queue(li);
+}
+END_TEST
+
 START_TEST(touchpad_scroll_natural_defaults)
 {
 	struct litest_device *dev = litest_current_device();
@@ -1549,6 +1569,154 @@ START_TEST(touchpad_scroll_natural)
 }
 END_TEST
 
+START_TEST(touchpad_edge_scroll)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libinput *li = dev->libinput;
+
+	litest_drain_events(li);
+
+	litest_touch_down(dev, 0, 99, 20);
+	litest_touch_move_to(dev, 0, 99, 20, 99, 80, 10, 0);
+	litest_touch_up(dev, 0);
+
+	libinput_dispatch(li);
+	litest_assert_scroll(li, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL, 10);
+	litest_assert_empty_queue(li);
+
+	litest_touch_down(dev, 0, 99, 80);
+	litest_touch_move_to(dev, 0, 99, 80, 99, 20, 10, 0);
+	litest_touch_up(dev, 0);
+
+	libinput_dispatch(li);
+	litest_assert_scroll(li, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL, -10);
+	litest_assert_empty_queue(li);
+
+	litest_touch_down(dev, 0, 20, 99);
+	litest_touch_move_to(dev, 0, 20, 99, 70, 99, 10, 0);
+	litest_touch_up(dev, 0);
+
+	libinput_dispatch(li);
+	litest_assert_scroll(li, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL, 10);
+	litest_assert_empty_queue(li);
+
+	litest_touch_down(dev, 0, 70, 99);
+	litest_touch_move_to(dev, 0, 70, 99, 20, 99, 10, 0);
+	litest_touch_up(dev, 0);
+
+	libinput_dispatch(li);
+	litest_assert_scroll(li, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL, -10);
+	litest_assert_empty_queue(li);
+}
+END_TEST
+
+START_TEST(touchpad_edge_scroll_slow_distance)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libinput *li = dev->libinput;
+	struct libinput_event *event;
+	struct libinput_event_pointer *ptrev;
+
+	litest_drain_events(li);
+
+	litest_touch_down(dev, 0, 99, 20);
+	litest_touch_move_to(dev, 0, 99, 20, 99, 80, 60, 10);
+	litest_touch_up(dev, 0);
+	libinput_dispatch(li);
+
+	event = libinput_get_event(li);
+	ck_assert_notnull(event);
+
+	while (libinput_next_event_type(li) != LIBINPUT_EVENT_NONE) {
+		double axisval;
+		ck_assert_int_eq(libinput_event_get_type(event),
+				 LIBINPUT_EVENT_POINTER_AXIS);
+		ptrev = libinput_event_get_pointer_event(event);
+
+		axisval = libinput_event_pointer_get_axis_value(ptrev,
+				 LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL);
+		ck_assert(axisval > 0.0);
+
+		/* this is to verify we test the right thing, if the value
+		   is greater than scroll.threshold we triggered the wrong
+		   condition */
+		ck_assert(axisval < 5.0);
+
+		libinput_event_destroy(event);
+		event = libinput_get_event(li);
+	}
+
+	litest_assert_empty_queue(li);
+	libinput_event_destroy(event);
+}
+END_TEST
+
+START_TEST(touchpad_edge_scroll_no_motion)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libinput *li = dev->libinput;
+
+	litest_drain_events(li);
+
+	litest_touch_down(dev, 0, 99, 20);
+	litest_touch_move_to(dev, 0, 99, 20, 99, 60, 10, 0);
+	/* moving outside -> no motion event */
+	litest_touch_move_to(dev, 0, 99, 60, 20, 80, 10, 0);
+	/* moving down outside edge once scrolling had started -> scroll */
+	litest_touch_move_to(dev, 0, 20, 80, 40, 99, 10, 0);
+	litest_touch_up(dev, 0);
+	libinput_dispatch(li);
+
+	litest_assert_scroll(li, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL, 5);
+	litest_assert_empty_queue(li);
+}
+END_TEST
+
+START_TEST(touchpad_edge_scroll_no_edge_after_motion)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libinput *li = dev->libinput;
+
+	litest_drain_events(li);
+
+	/* moving into the edge zone must not trigger scroll events */
+	litest_touch_down(dev, 0, 20, 20);
+	litest_touch_move_to(dev, 0, 20, 20, 99, 20, 10, 0);
+	litest_touch_move_to(dev, 0, 99, 20, 99, 80, 10, 0);
+	litest_touch_up(dev, 0);
+	libinput_dispatch(li);
+
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
+	litest_assert_empty_queue(li);
+}
+END_TEST
+
+START_TEST(touchpad_edge_scroll_source)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libinput *li = dev->libinput;
+	struct libinput_event *event;
+	struct libinput_event_pointer *ptrev;
+
+	litest_drain_events(li);
+
+	litest_touch_down(dev, 0, 99, 20);
+	litest_touch_move_to(dev, 0, 99, 20, 99, 80, 10, 0);
+	litest_touch_up(dev, 0);
+
+	litest_wait_for_event_of_type(li, LIBINPUT_EVENT_POINTER_AXIS, -1);
+
+	while ((event = libinput_get_event(li))) {
+		ck_assert_int_eq(libinput_event_get_type(event),
+				 LIBINPUT_EVENT_POINTER_AXIS);
+		ptrev = libinput_event_get_pointer_event(event);
+		ck_assert_int_eq(libinput_event_pointer_get_axis_source(ptrev),
+				 LIBINPUT_POINTER_AXIS_SOURCE_FINGER);
+		libinput_event_destroy(event);
+	}
+}
+END_TEST
+
 START_TEST(touchpad_tap_is_available)
 {
 	struct litest_device *dev = litest_current_device();
@@ -1697,8 +1865,6 @@ START_TEST(touchpad_palm_detect_palm_becomes_pointer)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
-	struct libinput_event *ev;
-	enum libinput_event_type type;
 
 	if (!touchpad_has_palm_detect_size(dev))
 		return;
@@ -1711,15 +1877,7 @@ START_TEST(touchpad_palm_detect_palm_becomes_pointer)
 
 	libinput_dispatch(li);
 
-	ev = libinput_get_event(li);
-	ck_assert_notnull(ev);
-	do {
-		type = libinput_event_get_type(ev);
-		ck_assert_int_eq(type, LIBINPUT_EVENT_POINTER_MOTION);
-
-		libinput_event_destroy(ev);
-		ev = libinput_get_event(li);
-	} while (ev);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	litest_assert_empty_queue(li);
 }
@@ -1729,8 +1887,6 @@ START_TEST(touchpad_palm_detect_no_palm_moving_into_edges)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
-	struct libinput_event *ev;
-	enum libinput_event_type type;
 
 	if (!touchpad_has_palm_detect_size(dev))
 		return;
@@ -1746,16 +1902,7 @@ START_TEST(touchpad_palm_detect_no_palm_moving_into_edges)
 	litest_touch_move_to(dev, 0, 99, 50, 99, 90, 5, 0);
 	libinput_dispatch(li);
 
-	type = libinput_next_event_type(li);
-	do {
-
-		ck_assert_int_eq(type, LIBINPUT_EVENT_POINTER_MOTION);
-		ev = libinput_get_event(li);
-		libinput_event_destroy(ev);
-
-		type = libinput_next_event_type(li);
-		libinput_dispatch(li);
-	} while (type != LIBINPUT_EVENT_NONE);
+	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	litest_touch_up(dev, 0);
 	libinput_dispatch(li);
@@ -1770,7 +1917,7 @@ START_TEST(touchpad_left_handed)
 	struct libinput *li = dev->libinput;
 	enum libinput_config_status status;
 
-	status = libinput_device_config_buttons_set_left_handed(d, 1);
+	status = libinput_device_config_left_handed_set(d, 1);
 	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
 	litest_drain_events(li);
@@ -1815,7 +1962,7 @@ START_TEST(touchpad_left_handed_clickpad)
 	struct libinput *li = dev->libinput;
 	enum libinput_config_status status;
 
-	status = libinput_device_config_buttons_set_left_handed(d, 1);
+	status = libinput_device_config_left_handed_set(d, 1);
 	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
 	litest_drain_events(li);
@@ -1866,7 +2013,7 @@ START_TEST(touchpad_left_handed_clickfinger)
 	struct libinput *li = dev->libinput;
 	enum libinput_config_status status;
 
-	status = libinput_device_config_buttons_set_left_handed(d, 1);
+	status = libinput_device_config_left_handed_set(d, 1);
 	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
 	litest_drain_events(li);
@@ -1909,7 +2056,7 @@ START_TEST(touchpad_left_handed_tapping)
 
 	libinput_device_config_tap_set_enabled(dev->libinput_device,
 					       LIBINPUT_CONFIG_TAP_ENABLED);
-	status = libinput_device_config_buttons_set_left_handed(d, 1);
+	status = libinput_device_config_left_handed_set(d, 1);
 	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
 	litest_drain_events(li);
@@ -1940,7 +2087,7 @@ START_TEST(touchpad_left_handed_tapping_2fg)
 
 	libinput_device_config_tap_set_enabled(dev->libinput_device,
 					       LIBINPUT_CONFIG_TAP_ENABLED);
-	status = libinput_device_config_buttons_set_left_handed(d, 1);
+	status = libinput_device_config_left_handed_set(d, 1);
 	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
 	litest_drain_events(li);
@@ -1976,7 +2123,7 @@ START_TEST(touchpad_left_handed_delayed)
 	litest_button_click(dev, BTN_LEFT, 1);
 	libinput_dispatch(li);
 
-	status = libinput_device_config_buttons_set_left_handed(d, 1);
+	status = libinput_device_config_left_handed_set(d, 1);
 	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
 	litest_button_click(dev, BTN_LEFT, 0);
@@ -1993,7 +2140,7 @@ START_TEST(touchpad_left_handed_delayed)
 	litest_button_click(dev, BTN_LEFT, 1);
 	libinput_dispatch(li);
 
-	status = libinput_device_config_buttons_set_left_handed(d, 0);
+	status = libinput_device_config_left_handed_set(d, 0);
 	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
 	litest_button_click(dev, BTN_RIGHT, 0);
@@ -2026,7 +2173,7 @@ START_TEST(touchpad_left_handed_clickpad_delayed)
 	litest_button_click(dev, BTN_LEFT, 1);
 	libinput_dispatch(li);
 
-	status = libinput_device_config_buttons_set_left_handed(d, 1);
+	status = libinput_device_config_left_handed_set(d, 1);
 	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
 	litest_button_click(dev, BTN_LEFT, 0);
@@ -2045,7 +2192,7 @@ START_TEST(touchpad_left_handed_clickpad_delayed)
 	litest_button_click(dev, BTN_LEFT, 1);
 	libinput_dispatch(li);
 
-	status = libinput_device_config_buttons_set_left_handed(d, 0);
+	status = libinput_device_config_left_handed_set(d, 0);
 	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
 	litest_button_click(dev, BTN_LEFT, 0);
@@ -2122,9 +2269,16 @@ int main(int argc, char **argv) {
 
 	litest_add("touchpad:scroll", touchpad_2fg_scroll, LITEST_TOUCHPAD, LITEST_SINGLE_TOUCH);
 	litest_add("touchpad:scroll", touchpad_2fg_scroll_slow_distance, LITEST_TOUCHPAD, LITEST_SINGLE_TOUCH);
+	litest_add("touchpad:scroll", touchpad_2fg_scroll_return_to_motion, LITEST_TOUCHPAD, LITEST_SINGLE_TOUCH);
+	litest_add("touchpad:scroll", touchpad_2fg_scroll_source, LITEST_TOUCHPAD, LITEST_SINGLE_TOUCH);
 	litest_add("touchpad:scroll", touchpad_scroll_natural_defaults, LITEST_TOUCHPAD, LITEST_ANY);
 	litest_add("touchpad:scroll", touchpad_scroll_natural_enable_config, LITEST_TOUCHPAD, LITEST_ANY);
 	litest_add("touchpad:scroll", touchpad_scroll_natural, LITEST_TOUCHPAD, LITEST_SINGLE_TOUCH);
+	litest_add("touchpad:scroll", touchpad_edge_scroll, LITEST_TOUCHPAD|LITEST_SINGLE_TOUCH, LITEST_ANY);
+	litest_add("touchpad:scroll", touchpad_edge_scroll_no_motion, LITEST_TOUCHPAD|LITEST_SINGLE_TOUCH, LITEST_ANY);
+	litest_add("touchpad:scroll", touchpad_edge_scroll_no_edge_after_motion, LITEST_TOUCHPAD|LITEST_SINGLE_TOUCH, LITEST_ANY);
+	litest_add("touchpad:scroll", touchpad_edge_scroll_slow_distance, LITEST_TOUCHPAD|LITEST_SINGLE_TOUCH, LITEST_ANY);
+	litest_add("touchpad:scroll", touchpad_edge_scroll_source, LITEST_TOUCHPAD|LITEST_SINGLE_TOUCH, LITEST_ANY);
 
 	litest_add("touchpad:palm", touchpad_palm_detect_at_edge, LITEST_TOUCHPAD, LITEST_ANY);
 	litest_add("touchpad:palm", touchpad_palm_detect_at_bottom_corners, LITEST_TOUCHPAD, LITEST_CLICKPAD);
