@@ -27,7 +27,6 @@
 #include <cairo.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <getopt.h>
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -40,8 +39,12 @@
 #include <libinput.h>
 #include <libinput-util.h>
 
+#include "shared.h"
+
 #define clip(val_, min_, max_) min((max_), max((min_), (val_)))
 
+struct tools_options options;
+
 struct touch {
 	int active;
 	int x, y;
@@ -95,12 +98,6 @@ msg(const char *fmt, ...)
 	va_end(args);
 }
 
-static void
-usage(void)
-{
-	printf("%s [path/to/device]\n", program_invocation_short_name);
-}
-
 static gboolean
 draw(GtkWidget *widget, cairo_t *cr, gpointer data)
 {
@@ -361,20 +358,20 @@ static void
 handle_event_axis(struct libinput_event *ev, struct window *w)
 {
 	struct libinput_event_pointer *p = libinput_event_get_pointer_event(ev);
-	enum libinput_pointer_axis axis = libinput_event_pointer_get_axis(p);
-	double v = libinput_event_pointer_get_axis_value(p);
+	double v, h;
 
-	switch (axis) {
-	case LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL:
+	v = libinput_event_pointer_get_axis_value(p,
+		      LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL);
+	h = libinput_event_pointer_get_axis_value(p,
+		      LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL);
+
+	if (v != 0.0) {
 		w->vy += (int)v;
 		w->vy = clip(w->vy, 0, w->height);
-		break;
-	case LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL:
+	}
+	if (h != 0.0) {
 		w->hx += (int)v;
 		w->hx = clip(w->hx, 0, w->width);
-		break;
-	default:
-		abort();
 	}
 }
 
@@ -490,35 +487,6 @@ sockets_init(struct libinput *li)
 	g_io_add_watch(c, G_IO_IN, handle_event_libinput, li);
 }
 
-static int
-parse_opts(int argc, char *argv[])
-{
-	while (1) {
-		static struct option long_options[] = {
-			{ "help", no_argument, 0, 'h' },
-		};
-
-		int option_index = 0;
-		int c;
-
-		c = getopt_long(argc, argv, "h", long_options,
-				&option_index);
-		if (c == -1)
-			break;
-
-		switch(c) {
-		case 'h':
-			usage();
-			return 0;
-		default:
-			usage();
-			return 1;
-		}
-	}
-
-	return 0;
-}
-
 static int
 open_restricted(const char *path, int flags, void *user_data)
 {
@@ -546,16 +514,18 @@ main(int argc, char *argv[])
 
 	gtk_init(&argc, &argv);
 
-	if (parse_opts(argc, argv) != 0)
+	tools_init_options(&options);
+
+	if (tools_parse_args(argc, argv, &options) != 0)
 		return 1;
 
 	udev = udev_new();
 	if (!udev)
 		error("Failed to initialize udev\n");
 
-	li = libinput_udev_create_context(&interface, &w, udev);
-	if (!li || libinput_udev_assign_seat(li, "seat0") != 0)
-		error("Failed to initialize context from udev\n");
+	li = tools_open_backend(&options, &w, &interface);
+	if (!li)
+		return 1;
 
 	window_init(&w);
 	sockets_init(li);
